@@ -22,7 +22,15 @@ if TYPE_CHECKING:
 
 __all__ = ['ProgressBarLogger']
 
-_IS_TRAIN_TO_KEYS_TO_LOG = {True: ['loss/train'], False: ['metrics/eval/Accuracy']}
+_IS_TRAIN_TO_KEYS_TO_LOG = {
+    True: ['loss/train'],
+    False: [
+        'metrics/eval/Accuracy',
+        'metrics/eval/BinaryAccuracy',
+        'metrics/eval/MulticlassAccuracy',
+        'metrics/eval/MultilabelAccuracy',
+    ],
+}
 
 
 class _ProgressBar:
