@@ -10,6 +10,6 @@ _task = 'Image Classification'
 _dataset = 'MNIST'
 _name = 'SimpleConvNet'
 _quality = ''
-_metric = 'Accuracy'
+_metric = 'MulticlassAccuracy'
 _ttt = '?'
 _hparams = 'classify_mnist_cpu.yaml'
