@@ -9,9 +9,8 @@ the ImageNet dataset.
 See the :doc:`Model Card </model_cards/resnet>` for more details.
 """
 from composer.models.resnet.model import composer_resnet
-from composer.models.resnet.resnet_hparams import ResNetHparams as ResNetHparams
 
-__all__ = ['ResNetHparams', 'composer_resnet']
+__all__ = ['composer_resnet']
 
 _metadata = {
     'resnet18': {
